NAME
benchmark.pl - Compare DateTime and DateTime::Lite performance
SYNOPSIS
cd DateTime-Lite-vX.X.X
perl Makefile.PL && make
perl -Iblib/lib -Iblib/arch scripts/benchmark.pl
perl scripts/benchmark.pl --iterations 20000
perl scripts/benchmark.pl --csv > results.csv
DESCRIPTION
Forks the process before loading any module so that every measurement runs in a clean %INC. Results are serialised to temp files and aggregated by the parent.